"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vdom_utils_1 = require("vdom-utils");
class JsxRenderer {
    constructor(options = {}) {
        this.html = "";
        const defaultOpts = { indent: 2 };
        Object.assign(this, defaultOpts, options);
    }
    reset() {
        this.html = "";
    }
    onProp(name, value, depth) {
        const indent = (depth + 1) * this.indent;
        this.html += "\n" + vdom_utils_1.padStart(name + '="' + value + '"', indent);
    }
    onOpenTag(name, hasAttributes, isVoid, depth) {
        this.html += vdom_utils_1.padStart("<" + name, depth * this.indent);
        if (!hasAttributes) {
            this.html += isVoid ? " />\n" : "";
        }
    }
    onOpenTagClose(name, hasAttributes, isVoid, hasChildren, depth) {
        if (hasAttributes) {
            const closer = isVoid ? "/>\n" : ">";
            this.html += "\n" + vdom_utils_1.padStart(closer, depth * this.indent);
        }
        else if (!isVoid) {
            this.html += ">";
        }
        if (hasChildren) {
            this.html += "\n";
        }
    }
    onTextNode(text, depth) {
        this.html += vdom_utils_1.padStart(text + "\n", depth * this.indent);
    }
    onCloseTag(name, isVoid, depth) {
        if (!isVoid) {
            this.html += vdom_utils_1.padStart("</" + name + ">", depth * this.indent) + "\n";
        }
    }
    onDangerousInnerHTML(html) {
        this.html += html;
    }
}
exports.default = JsxRenderer;
//# sourceMappingURL=JsxRenderer.js.map